# -*- coding: utf-8 -*-

# This file is part of Pigeon Planner.

# Pigeon Planner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# Pigeon Planner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Pigeon Planner.  If not, see <http://www.gnu.org/licenses/>


from pigeonplanner.ui import builder
from pigeonplanner.ui import filechooser
from pigeonplanner.core import backup
from pigeonplanner.database.manager import dbmanager


class BackupDialog(builder.GtkBuilder):
    (COL_OBJECT,
     COL_INCLUDE,
     COL_INFO) = range(3)

    def __init__(self, parent):
        builder.GtkBuilder.__init__(self, "Backup.ui", ["dialogbackup", "liststoredb", "imagebackup"])
        self.widgets.dialogbackup.set_transient_for(parent)

        self.widgets.pathchooser = filechooser.PathChooser()
        self.widgets.pathchooser.show()
        self.widgets.alignlocation.add(self.widgets.pathchooser)

    def on_dialogbackup_delete_event(self, widget, event):
        self.widgets.dialogbackup.hide()
        return True

    def on_include_toggled(self, renderer, path):
        self.widgets.liststoredb[path][self.COL_INCLUDE] =\
                            not self.widgets.liststoredb[path][self.COL_INCLUDE]

    def on_create_clicked(self, widget):
        pass

    def on_cancel_clicked(self, widget):
        self.widgets.dialogbackup.hide()

    def run(self):
        self.widgets.liststoredb.clear()
        for dbobj in dbmanager.get_databases():
            self.widgets.liststoredb.append([dbobj, True, dbobj.name])

        self.widgets.dialogbackup.show()


class RestoreDialog(builder.GtkBuilder):
    def __init__(self, parent):
        builder.GtkBuilder.__init__(self, "Backup.ui", ["dialogrestore", "imagerestore"])
        self.widgets.dialogrestore.set_transient_for(parent)

        self.widgets.filechooser = filechooser.FileChooser()
        self.widgets.filechooser.connect("file-set", self.on_filechooser_file_set)
        self.widgets.filechooser.add_backup_filter()
        self.widgets.filechooser.show()
        self.widgets.alignlocation.add(self.widgets.filechooser)

    def on_dialogrestore_delete_event(self, widget, event):
        self.widgets.dialogrestore.hide()
        return True

    def on_restore_clicked(self, widget):
        pass

    def on_cancel_clicked(self, widget):
        self.widgets.dialogrestore.hide()

    def on_filechooser_file_set(self, button):
        path = button.get_filename()
        valid = backup.is_valid_archive(path)
        self.widgets.restore.set_sensitive(valid)

    def run(self):
        self.widgets.dialogrestore.show()
